@@ -143,7 +143,7 @@ class Update(MethodsInterface):
             EmergeCache.logger.logger.setLevel(logging.WARNING)
         self.emerge_cache.check_list = (
             self.emerge_cache.check_list +
-            map(emerge_parser.GitCheckvalue,
+            map(lambda x:emerge_parser.GitCheckvalue(x, self.getGit()),
                 self.clVars.Get('update.cl_update_rep_path')))
         self.update_map = {}
         self.refresh_binhost = False
@@ -153,13 +153,16 @@ class Update(MethodsInterface):
     def get_prog_path(self, program_name):
         return getProgPath(program_name)
 
+    def getGit(self):
+        return self.clVars.Get('cl_update_git')
+
     def _syncRepository(self, name, url, rpath, revision,
                         cb_progress=None, clean=False, notask=False):
         """
         Синхронизировать репозитори
         """
         dv = self.clVars
-        git = Git()
+        git = self.getGit()
         info_outdated = False
         old_dir = "%s.old" % git._gitDir(rpath)
         if path.exists(old_dir):
@@ -299,7 +302,7 @@ class Update(MethodsInterface):
         dv = self.clVars
         rpath = \
             dv.select('cl_update_rep_path', cl_update_rep_name=repname, limit=1)
-        git = Git()
+        git = self.getGit()
         self.addProgress()
         git.trimRepository(rpath, cb_progress=self.setProgress)
         return True
@@ -319,7 +322,7 @@ class Update(MethodsInterface):
         if not url or not rpath:
             raise UpdateError(_("Configuration variables for repositories "
                                 "are not setup"))
-        git = Git()
+        git = self.getGit()
         if not git.checkUrl(url):
             raise UpdateError(_("Git %s is unavailable") % url)
         chroot_path = path.normpath(self.clVars.Get('cl_chroot_path'))
@@ -382,6 +385,12 @@ class Update(MethodsInterface):
             if repname not in ("portage", "gentoo"):
                 layman.add(repname, url, rpath_orig)
         finally:
+            try:
+                if (path.exists(rpath) and
+                            Git.parse_url(url)[0] == Git.GitProtocol.SSH):
+                    os.chmod(rpath, 0700)
+            except OSError:
+                pass
             mtime.restore()
         return True
 
@@ -1082,8 +1091,12 @@ class Update(MethodsInterface):
             dv.importUpdate()
             dv.flIniFile()
             dv.Set('cl_action', action, force=True)
-            dv.Set('cl_templates_locate',
-                   self.clVars.Get('cl_update_templates_locate'))
+            try:
+                dv.Set('cl_templates_locate',
+                       self.clVars.Get('cl_update_templates_locate'))
+            except VariableError:
+                self.printERROR(_("Failed to apply profiles templates"))
+                return True
             dv.Set("cl_chroot_path", '/', True)
             dv.Set("cl_root_path", '/', True)
             for copyvar in ("cl_dispatch_conf", "cl_verbose_set",
